from .base_enum import BaseEnum


class MapSort(BaseEnum):
    FIRST_PUBLISHED = "FIRST_PUBLISHED"
    LAST_PUBLISHED = "LAST_PUBLISHED"
    UPDATED = "UPDATED"
    CREATED = "CREATED"
